registry

package
v0.0.10 Latest Latest
Warning

This package is not in the latest version of its module.

Go to latest
Published: Apr 6, 2026 License: MIT Imports: 13 Imported by: 0

Documentation

Index

Constants

This section is empty.

Variables

This section is empty.

Functions

func Pull

func Pull(ctx context.Context, st *store.Store, ref string) (ocispec.Descriptor, error)

Pull downloads a skill artifact from a remote registry to the local store.

func Push

func Push(ctx context.Context, st *store.Store, ref string) error

Push uploads a skill artifact from the local store to a remote registry.

Types

This section is empty.

Jump to