store

package
v0.0.10 Latest Latest
Warning

This package is not in the latest version of its module.

Go to latest
Published: Apr 6, 2026 License: MIT Imports: 16 Imported by: 0

Documentation

Index

Constants

const (
	MediaTypeSkillLayer  = "application/vnd.agentskills.skill.layer.v1+tar+gzip"
	MediaTypeSkillConfig = "application/vnd.agentskills.skill.config.v1+json"
	StoreDirName         = "skr/store"
)

Variables

This section is empty.

Functions

This section is empty.

Types

type Store

type Store struct {
	// contains filtered or unexported fields
}

func New

func New(path string) (*Store, error)

func (*Store) Build

func (s *Store) Build(ctx context.Context, srcDir string, tag string, annotations map[string]string) error

func (*Store) Delete

func (s *Store) Delete(ctx context.Context, target ocispec.Descriptor) error

Delete removes a descriptor from the store

func (*Store) Exists

func (s *Store) Exists(ctx context.Context, target ocispec.Descriptor) (bool, error)

Exists checks if a target descriptor exists in the store

func (*Store) Fetch

func (s *Store) Fetch(ctx context.Context, target ocispec.Descriptor) (io.ReadCloser, error)

Fetch retrieves content by digest

func (*Store) List

func (s *Store) List(ctx context.Context) ([]string, error)

List returns a list of all tags in the store

func (*Store) Prune

func (s *Store) Prune(ctx context.Context) (int, int64, error)

Prune removes all unreferenced blobs from the store

func (*Store) Push

func (s *Store) Push(ctx context.Context, desc ocispec.Descriptor, r io.Reader) error

Push pushes content to the store

func (*Store) Resolve

func (s *Store) Resolve(ctx context.Context, ref string) (ocispec.Descriptor, error)

Resolve resolves a reference (tag/digest) to a descriptor

func (*Store) Tag

func (s *Store) Tag(ctx context.Context, desc ocispec.Descriptor, reference string) error

Tag aliases a descriptor with a reference

Jump to